@@ -82,6 +82,7 @@ case "è incompatibile con la tariffa selezionata":	$messaggio = "est incompatib
 case "il":  					$messaggio = "the"; break;
 case " a":  					$messaggio = " in"; break;
 case "ln.":  					$messaggio = "ln."; break;
+case "Clienti":  				$messaggio = "Clients"; break;
 case "Si devono fare i seguenti spostamenti nei periodi della <div style=\"display: inline; color: blue;\">regola di assegnazione 1</div>":	$messaggio = "Movements that must be done in the periods of the <div style=\"display: inline; color: blue;\">assignment rule 1</div>"; break;
 case "Sono stati fatti i seguenti spostamenti nei periodi della <div style=\"display: inline; color: blue;\">regola di assegnazione 1</div>":	$messaggio = "Movements that have been done in the periods of the <div style=\"display: inline; color: blue;\">assignment rule 1</div>"; break;
 case "Esistono i seguenti clienti con un cognome e nome uguale o simile":	$messaggio = "There are already these clients with the same or similar surname and name"; break;
@@ -130,6 +131,16 @@ case "Commento":  				$messaggio = "Comment"; break;
 case "Si deve inserire almeno una persona che possa essere ospite principale":	$messaggio = "You must insert at least one person that can be main guest"; break;
 case "non si sono potuti usare":  		$messaggio = "It was not possible to use"; break;
 case "letti aggiuntivi perchè non c'era nessuna tipologia di persone con quel numero":	$messaggio = "extra beds as there was no people type with that number"; break;
+case "E-mail":  				$messaggio = "E-mail"; break;
+case "Seconda e-mail":  			$messaggio = "Second e-mail"; break;
+case "E-mail certificata (PEC) o codice destinatario":	$messaggio = "Certified e-mail"; break;
+case "email":  					$messaggio = "email"; break;
+case "2ª email":  				$messaggio = "2nd email"; break;
+case "PEC/codice":  				$messaggio = "certified email"; break;
+case "Per questa tariffa si deve inserire un numero minimo di":	$messaggio = "For this rate you have to insert at least"; break;
+case "persona":  				$messaggio = "person"; break;
+case "Usa il cliente della prenotazione originale":	$messaggio = "Use the client from the original reservation"; break;
+case "2° cognome":  				$messaggio = "2nd surname"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
