@@ -48,10 +48,12 @@ case "Il contenuto del file inviato non è corretto":				$messaggio = "Le conten
 case "Il formato del file è errato":  								$messaggio = "Le formt du Fichier est erroné"; break;
 case "Compresso":  				$messaggio = "Compressé"; break;
 case "alle":  					$messaggio = "at"; break;
+case "Backup":  				$messaggio = "Backup"; break;
 case "Non ho il permesso di scrittura sul file":	$messaggio = "I don't have write permissions on the file"; break;
 case "<b style=\"color: red;\">ATTENZIONE</b>: premendo su <b>\"<i>Continua</i>\"</b>, prima di ripristinare i dati dal <i>file</i>, tutti i dati del <i>database attuale</i> verranno <b>cancellati</b>":	$messaggio = "<b style=\"color: red;\">WARNING</b>: if you press <b>\"<i>Continue</i>\"</b>, before restoring the data from <i>file</i>, all data from <i>current database</i> will be <b>deleted</b>"; break;
 case "Normalmete 5432 o 5433 per Postgresql o 3306 per Mysql":	$messaggio = "Normally 5432 or 5433 for Postgresql or 3306 for Mysql"; break;
-case "La versione attuale di hoteldruid e quella del file non coincidono":	$messaggio = "The current version of hoteldruid and the one of the file are not the same"; break;
+case "La versione attuale di HotelDruid e quella del file non coincidono":	$messaggio = "The current version of HotelDruid and the one of the file are not the same"; break;
+case "La versione attuale e quella del file non coincidono":	$messaggio = "The current version and the one of the file are not the same"; break;
 case "Sistema di backup per HotelDruid":  	$messaggio = "Backup system for HotelDruid"; break;
 case "per salvarlo (eventualmente usa il bottone indietro del browser per tornare qui)":	$messaggio = "to save it (possibly use the browser back button to come back here)"; break;
 case "Ho fatto l'upload del file":		$messaggio = "You have uploaded the file"; break;
@@ -68,7 +70,7 @@ case "i documenti attuali verranno cancellati":	$messaggio = "current documents
 case "Ripristina i documenti dal file":  	$messaggio = "Restore documents from file"; break;
 case "Documenti ripristinati":  		$messaggio = "Documents restored"; break;
 case "Backup completo":  			$messaggio = "Complete backup"; break;
-case "Includi i modelli internet":  		$messaggio = "Include internet templates"; break;
+case "Includi le pagine per il sito web":  	$messaggio = "Include website pages"; break;
 case "creato il":  				$messaggio = "created"; break;
 case "copia":  					$messaggio = "copy"; break;
 case "il file di backup dai documenti predefiniti in":	$messaggio = "the backup file from default documents in"; break;
@@ -82,6 +84,7 @@ case "alcuni dati di questi anni potrebbero comunque venir persi":	$messaggio =
 case "tutti i documenti contenuti nel file":	$messaggio = "all the documents contained in file"; break;
 case "solo il documento":  			$messaggio = "only document"; break;
 case "Raggiunto il limite giornaliero di backup":	$messaggio = "You have reached the limit of daily backups"; break;
+case "Il file di backup contiene più di":  	$messaggio = "The backup file contains more than"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
