@@ -1,6 +1,6 @@
 <?php
 
-if (substr($messaggio,0,4) != "var_") {
+if (substr((string) $messaggio,0,4) != "var_") {
 switch ($messaggio) {
 
 # translate YES and NO in upper case
@@ -54,8 +54,6 @@ case "Disponibilità incerta per la tipologia scelta, per ulteriori informazioni
 case "Mostrare la caparra se presente?":  		$messaggio = "Montrez l'acompte si présent ?"; break;
 case "Mostrare quali sono i giorni pieni all'interno dei periodi dove non c'è più disponibilità?":			$messaggio = "Montrez quels sont les jours pleins à l'intérieur des périodes où il n'y a plus de disponibilité ?"; break;
 case "Indirizzo email a cui inviare le richieste di prenotazione":	$messaggio = "Adresse email à laquelle envoyer les demandes de réservation"; break;
-case "Mascherare la provenienza dell'email sull'envelope?":			$messaggio = "Masquer l'expéditeur de l'email sur l'enveloppe ?"; break;
-case "provare a cambiare se non si riescono a spedire le email":	$messaggio = "essayez de changer ceci si vous ne pouvez pas envoyer l'email"; break;
 case "Controlla la disponibilità":  			$messaggio = "Vérifiez la disponibilité"; break;
 case "dal":  									$messaggio = "de"; break;
 case "al":  									$messaggio = "à"; break;
@@ -167,6 +165,7 @@ case "M":  					$messaggio = "M"; break;
 case "F":  					$messaggio = "F"; break;
 case "chiedere":  				$messaggio = "ask"; break;
 case "il":  					$messaggio = "the"; break;
+case "Crea Pagine Web":  			$messaggio = "Create Web Pages"; break;
 case "Crea pagine per il sito web":  		$messaggio = "Create website pages"; break;
 case "Postgresql":  				$messaggio = "Postgresql"; break;
 case "Mysql":  					$messaggio = "Mysql"; break;
@@ -187,6 +186,8 @@ case "Crea la pagina per la disponibilità":  	$messaggio = "Create availability
 case "C'è ancora disponibilità":		$messaggio = "There is still availability"; break;
 case "E' necessario inserire il numero di persone per questa tipologia":	$messaggio = "The number of people is needed for this type"; break;
 case "Email":  					$messaggio = "Email"; break;
+case "Email alternativa":  			$messaggio = "Alternative email"; break;
+case "Email certificata (PEC) o codice destinatario":	$messaggio = "Certified email"; break;
 case "Richiesta di prenotazione inviata": 	$messaggio = "Request for reservation sent"; break;
 case "da":  					$messaggio = "from"; break;
 case "Una pagina chiamata":  			$messaggio = "A page called"; break;
@@ -264,7 +265,9 @@ case "eventuali pagine già presenti nella cartella":	$messaggio = "pages eventu
 case "verranno <b style=\"font-weight: normal; color: red;\">sovrascritte</b>":	$messaggio = "will be <b style=\"font-weight: normal; color: red;\">overwritten</b>"; break;
 case "Pagine importate":  			$messaggio = "Pages imported"; break;
 case "con i servizi opzionali selezionati":  	$messaggio = "with selected optional services"; break;
+case "Utilizzare le personalizzazioni (tipi di persone, liste di nazioni, regioni, ecc.) dell'utente":	$messaggio = "Use customizations (people types, lists of nations, regions, etc.) from user"; break;
 case "Url del file css per la modalità frame":	$messaggio = "Url of css file for framed mode"; break;
+case "Url del file javascript per la modalità frame":	$messaggio = "Url of javascript file for framed mode"; break;
 case "Utilizza per l'aspetto della pagina":  	$messaggio = "Use for page appearance"; break;
 case "html personalizzato":  			$messaggio = "custom html"; break;
 case "il tema chiamato":  			$messaggio = "the theme called"; break;
@@ -274,7 +277,7 @@ case "Data di partenza":  			$messaggio = "Departure date"; break;
 case "Tipologia":  				$messaggio = "Type"; break;
 case "default - frame orizzontale":  		$messaggio = "default - horizontal frame"; break;
 case "Condizioni da accettare nella form":  	$messaggio = "Agreements to be accepted in the form"; break;
-case "nomi dall'utente delle liste":		$messaggio = "names from lists user"; break;
+case "nomi dall'utente delle personalizzazioni":	$messaggio = "names from customizations user"; break;
 case "Accetto":  				$messaggio = "I accept"; break;
 case "documento":  				$messaggio = "document"; break;
 case "larghezza":  				$messaggio = "width"; break;
@@ -296,6 +299,7 @@ case "aggiunto al commento":  			$messaggio = "added to comment"; break;
 case "aggiunto al campo":  			$messaggio = "added to field"; break;
 case "del cliente":  				$messaggio = "in client data"; break;
 case "URL file css":  				$messaggio = "URL of css file"; break;
+case "URL file javascript":  			$messaggio = "URL of javascript file"; break;
 case "ci sono tariffe senza regola di assegnazione n. 2":	$messaggio = "there are rates without assignment rule n. 2"; break;
 case "Codice fiscale":  			$messaggio = "Fiscal code"; break;
 case "Partita iva":  				$messaggio = "VAT number"; break;
@@ -319,8 +323,20 @@ case "non sono associati a tariffe, alcune loro caratteristiche potrebbero venir
 case "Mostrare le date passate?":  		$messaggio = "Show past dates?"; break;
 case "titolo html":  				$messaggio = "html title"; break;
 case "titolo":  				$messaggio = "title"; break;
-case "Utilizzare le personalizzazioni (tipi di persone, liste di nazioni, regioni, ecc.) dell'utente":	$messaggio = "Use customizations (people types, lists of nations, regions, etc.) from user"; break;
 case "Si deve inserire almeno una persona che possa essere legalmente responsabile":	$messaggio = "You must include at least one person who can be legally responsible"; break;
+case "Solo quando non c'è disponibilità":  	$messaggio = "Only when there is no availability"; break;
+case "Sempre":  				$messaggio = "Always"; break;
+case "Raggruppamento":  			$messaggio = "Grouping"; break;
+case "Valuta della caparra":  			$messaggio = "Deposit currency"; break;
+case "Seconda email":  				$messaggio = "Second email"; break;
+case "PEC o codice destinatario":  		$messaggio = "Certified email"; break;
+case "non deve contenere \"php\" e deve terminare con \".js\"":	$messaggio = "must not contain \"php\" and must end with \".js\""; break;
+case "notte":  					$messaggio = "night"; break;
+case "notti":  					$messaggio = "nights"; break;
+case "cambia date":  				$messaggio = "change dates"; break;
+case "Per questa tariffa si deve inserire un minimo di":	$messaggio = "For this rate you have to insert at least"; break;
+case "Secondo cognome":  			$messaggio = "Second surname"; break;
+case "2° cognome":  				$messaggio = "2nd surname"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
@@ -328,7 +344,7 @@ case "":  		$messaggio = ""; break;
 case "mdl_disponibilita":  				$messaggio = "mdl_disponible"; break;
 
 } # fine switch ($messaggio)
-} # fine if (substr($messaggio,0,4) != "var_")
+} # fine if (substr((string) $messaggio,0,4) != "var_")
 
 
 else {
@@ -354,7 +370,6 @@ case "var_mostra_frase_alternativa_regola1":  			$messaggio = "var_montrer_phras
 case "var_mostra_caparra":  			$messaggio = "var_montrer_acompte"; break;
 case "var_mostra_richiesta_via_mail":  	$messaggio = "var_montrer_demande_par_mail"; break;
 case "var_indirizzo_email":  			$messaggio = "var_adresse_email"; break;
-case "var_maschera_email":  			$messaggio = "var_masquer_email_enveloppe"; break;
 case "var_mostra_giorni_pieni":  		$messaggio = "var_montre_jours_pleins"; break;
 case "var_apertura_tag_font":  			$messaggio = "var_font_balise_debut"; break;
 case "var_chiusura_tag_font":  			$messaggio = "var_font_balise_fin"; break;
@@ -466,6 +481,7 @@ case "var_colore_data_attiva_calendario":  	$messaggio = "var_color_active_calen
 case "var_colore_data_selezionata_calendario":	$messaggio = "var_color_selected_calendar_date"; break;
 case "var_stile_tabella_prenotazione":  	$messaggio = "var_reservation_table_style"; break;
 case "var_file_css_frame":  			$messaggio = "var_framed_css_file"; break;
+case "var_file_js_frame":  			$messaggio = "var_framed_js_file"; break;
 case "var_apri_nuova_finestra_da_frame":  	$messaggio = "var_open_new_window_from_frame"; break;
 case "var_larghezza_finestra_da_frame":  	$messaggio = "var_window_from_frame_width"; break;
 case "var_altezza_finestra_da_frame":  		$messaggio = "var_window_from_frame_height"; break;
@@ -476,10 +492,15 @@ case "var_allinea_disponibilita_con_arrivo":	$messaggio = "var_align_availabilit
 case "var_mostra_date_passate":  		$messaggio = "var_show_past_dates"; break;
 case "var_fr_E_necessario_inserire_il_numero_di_persone_ecc":	$messaggio = "var_fr_The_number_of_people_is_needed_etc"; break;
 case "var_fr_Email":  				$messaggio = "var_phr_Email"; break;
+case "var_fr_Email_alternativa":  		$messaggio = "var_phr_Alternative_email"; break;
+case "var_fr_Email_certificata_o_codice_destinatario":	$messaggio = "var_phr_Certified_email"; break;
 case "var_fr_Richiesta_di_prenotazione_inviata":	$messaggio = "var_phr_Request_for_reservation_sent"; break;
 case "var_fr_da":  				$messaggio = "var_phr_from2"; break;
 case "var_fre_Email":  				$messaggio = "var_phre_Email"; break;
+case "var_fre_Email_alternativa":  		$messaggio = "var_phre_Alternative_email"; break;
+case "var_fre_Email_certificata_o_codice_destinatario":	$messaggio = "var_phre_Certified_email"; break;
 case "var_fre_Riferimento":  			$messaggio = "var_phre_Reference"; break;
+case "var_fre_Valuta_della_caparra":  		$messaggio = "var_phre_Deposit_currency"; break;
 case "var_fr_Richesta_prenotazione":  		$messaggio = "var_phr_Reservation_request"; break;
 case "var_cerca_appartamenti_vicini":  		$messaggio = "var_search_nearby_apartments"; break;
 case "var_fr_Totale":  				$messaggio = "var_phr_Total"; break;
@@ -511,6 +532,8 @@ case "var_utente_messaggio":  			$messaggio = "var_message_user"; break;
 case "var_chiedi_cognome":  			$messaggio = "var_ask_surname"; break;
 case "var_chiedi_nome":  			$messaggio = "var_ask_name"; break;
 case "var_chiedi_email":  			$messaggio = "var_ask_email"; break;
+case "var_chiedi_email2":  			$messaggio = "var_ask_email2"; break;
+case "var_chiedi_email_cert":  			$messaggio = "var_ask_cert_email"; break;
 case "var_chiedi_sesso":  			$messaggio = "var_ask_sex"; break;
 case "var_chiedi_datanascita":  		$messaggio = "var_ask_birthdate"; break;
 case "var_chiedi_documento":  			$messaggio = "var_ask_document"; break;
@@ -528,6 +551,7 @@ case "var_chiedi_codfiscale":  			$messaggio = "var_ask_fiscalcode"; break;
 case "var_chiedi_partitaiva":  			$messaggio = "var_ask_vatnumber"; break;
 case "var_chiedi_commento":  			$messaggio = "var_ask_comment"; break;
 case "var_chiedi_oracheckin":  			$messaggio = "var_ask_checkintime"; break;
+case "var_chiedi_valutapagamento":  		$messaggio = "var_ask_paymentcurrency"; break;
 case "var_chiedi_metodopagamento":  		$messaggio = "var_ask_paymentmethod"; break;
 case "var_metodi_pagamento_da_chiedere":  	$messaggio = "var_payment_methods_to_ask"; break;
 case "var_nomi_metodi_pagamento_imposti":  	$messaggio = "var_imposed_payment_methods_names"; break;
@@ -553,6 +577,7 @@ case "var_fr_Fax":  				$messaggio = "var_phr_Fax"; break;
 case "var_fr_Codice_fiscale":  			$messaggio = "var_phr_Fiscal_code"; break;
 case "var_fr_Partita_iva":  			$messaggio = "var_phr_VAT_number"; break;
 case "var_fr_Orario_stimato_di_arrivo":  	$messaggio = "var_phr_Estimated_arrival_time"; break;
+case "var_fr_Valuta_della_caparra":		$messaggio = "var_phr_Deposit_currency"; break;
 case "var_fr_Metodo_di_pagamento_della_caparra":	$messaggio = "var_phr_Deposit_payment_method"; break;
 case "var_fre_Cognome":  			$messaggio = "var_phre_Surname"; break;
 case "var_fre_Genere":  			$messaggio = "var_phre_Gender"; break;
@@ -594,12 +619,18 @@ case "var_fr_posizioni_vicine":  		$messaggio = "var_phr_nearby_positions"; brea
 case "var_fr_con_posizioni_vicine":  		$messaggio = "var_phr_with_nearby_positions"; break;
 case "var_fr_Codice_promozionale":  		$messaggio = "var_phr_Promotional_code"; break;
 case "var_fr_Codice_promozionale_applicato":  	$messaggio = "var_phr_Promotional_code_applied"; break;
-case "var_":  		$messaggio = "var_"; break;
-case "var_":  		$messaggio = "var_"; break;
 case "var_fr_Si_deve_inserire_almeno_una_persona_che_possa_ecc":	$messaggio = "var_phr_You_must_include_at_least_one_person_who_can_etc"; break;
+case "var_fr_notte":  				$messaggio = "var_phr_night"; break;
+case "var_fr_notti":  				$messaggio = "var_phr_nights"; break;
+case "var_fr_cambia_date":  			$messaggio = "var_phr_change_dates"; break;
+case "var_fr_Per_questa_tariffa_si_deve_inserire_un_minimo_di":	$messaggio = "var_phr_For_this_rate_you_have_to_insert_at_least"; break;
+case "var_":  		$messaggio = "var_"; break;
+case "var_":  		$messaggio = "var_"; break;
+case "var_chiedi_cognome2":  			$messaggio = "var_ask_surname2"; break;
+case "var_fr_Secondo_cognome":  		$messaggio = "var_phr_Second_surname"; break;
 } # fine switch ($messaggio)
-} # fine else if (substr($messaggio,0,4) != "var_")
+} # fine else if (substr((string) $messaggio,0,4) != "var_")
 
 
 
-?>
\ No newline at end of file
+?>
