@@ -15,6 +15,8 @@ case "Password":  								$messaggio = "Mot de passe"; break;
 case "Commento da aggiungere al titolo di questa installazione":	$messaggio = "Commentez pour être ajouté au titre de cette installation"; break;
 case "Crea la subordinazione":  				$messaggio = "Créez la subordination"; break;
 case "Usa compressione":  			$messaggio = "Utiliser la compression"; break;
+case "nella":  					$messaggio = "in"; break;
+case "Interconnessioni":  			$messaggio = "Interconnections"; break;
 case "Non si è potuto portare a termine l'<div style=\"display: inline; color: red;\">aggiornamento</div>":	$messaggio = "<div style=\"display: inline; color: red;\">Update</div> failed"; break;
 case "<div style=\"display: inline; color: red;\"><b>ATTENZIONE</b></div>: premendo su <b>\"<i>Continua</i>\"</b> tutti i dati del <i>database attuale</i> verranno <b>cancellati</b>":	$messaggio = "<div style=\"display: inline; color: red;\"><b>WARNING</b></div>: if you press <b>\"<i>Continue</i>\"</b> all data from <i>current database</i> will be <b>deleted</b>"; break;
 case "Interconnessioni con sorgenti esterne di dati":	$messaggio = "Interconnections with external data sources"; break;
@@ -32,15 +34,18 @@ case "Non si è potuto scaricare il backup remoto":	$messaggio = "It was not pos
 case "Non si è potuto stabilire la connessione":	$messaggio = "It was not possible to establish the connection"; break;
 case "Non ho i permassi di scrittura sulla cartella dati":	$messaggio = "I don't have write premissions on dati folder"; break;
 case "Prova a mantenere i dati degli anni non presenti nell'installazione remota":	$messaggio = "Try to retain data of years not present in remote installation"; break;
-case "nella pagina delle interconnessioni":  	$messaggio = "in interconnections page"; break;
+case "pagina delle interconnessioni":  		$messaggio = "interconnections page"; break;
 case "Modifica la regola di assegnazione":  	$messaggio = "Modify the assignment rule"; break;
 case "La prenotazione cancellata non era presente nel database":	$messaggio = "The deleted reservation was not present in the database"; break;
 case "gruppo":  				$messaggio = "group"; break;
 case "Attenzione":  				$messaggio = "Warning"; break;
 case "carta di credito non salvata":  		$messaggio = "credit card not saved"; break;
+case "Se vuoi collegare altri account per una interconnessione già attiva inquesta pagina, allora":	$messaggio = "If you want to connect other accounts for an interconnection already active on this page, then"; break;
+case "aggiungi altre interconnessioni":  	$messaggio = "add more interconnections"; break;
+case "nella pagina delle interconnessioni":  	$messaggio = "in the interconnections page"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
 } # fine switch ($messaggio)
 
-?>
\ No newline at end of file
+?>
