@@ -189,6 +189,8 @@ case "Possibilità di modificare le prenotazioni vicine":	$messaggio = "Possibil
 case "non potrà modificare le <b>prenotazioni vicine</b> nel":	$messaggio = "will not be able to modify <b>close reservations</b> in"; break;
 case "potrà modificare le <b>prenotazioni vicine</b> nel":	$messaggio = "will be able to modify <b>close reservations</b> in"; break;
 case "nel":  					$messaggio = "in"; break;
+case "e":  					$messaggio = "and"; break;
+case "Privilegi Utenti":  			$messaggio = "Users Privileges"; break;
 case "Solo":  					$messaggio = "Only"; break;
 case "i propri":  				$messaggio = "his own"; break;
 case "dei propri":  				$messaggio = "his own"; break;
@@ -368,9 +370,42 @@ case "senza mostrarli":  			$messaggio = "without showing them"; break;
 case "Modifica delle tipologie di persone":  	$messaggio = "Modify people types"; break;
 case "potrà modificare le sue <b>tipologie di persone</b>":	$messaggio = "will be able to modify his <b>people types</b>"; break;
 case "non potrà più modificare le sue <b>tipologie di persone</b>":	$messaggio = "will not be able to modify his <b>people types</b>"; break;
+case "Modifica delle valute":  			$messaggio = "Modify currencies"; break;
+case "potrà modificare le sue <b>valute</b>":  	$messaggio = "will be able to modify his <b>currencies</b>"; break;
+case "non potrà più modificare le sue <b>valute</b>":	$messaggio = "will not be able to modify his <b>currencies</b>"; break;
+case "solo per lui":  				$messaggio = "only for him"; break;
+case "anche per i suoi gruppi":  		$messaggio = "also for his groups"; break;
+case "anche per tutti gli utenti":  		$messaggio = "also for all the users"; break;
+case "e quelle di utenti appartenenti ai suoi gruppi":	$messaggio = "and the ones from users belonging to his groups"; break;
+case "e quelle di tutti gli altri utenti":  	$messaggio = "and the ones from all users"; break;
+case "Cancellare le prenotazioni in modo permanente":	$messaggio = "Delete reservations permanently"; break;
+case "non <b>cancellerà mai in modo permanente</b> le prenotazioni nel":	$messaggio = "will <b>never permanently delete</b> reservations in"; break;
+case "potrà scegliere se <b>cancellare in modo permanente</b> le prenotazioni nel":	$messaggio = "will choose if <b>permanently delete</b> reservations in"; break;
+case "<b>cancellerà sempre in modo permanete</b> le prenotazioni nel":	$messaggio = "will <b>always permanently delete</b> reservations in"; break;
+case "Possibilità di modificare le <i>regole di assegnazione</i>":	$messaggio = "Possibility to modify the <i>assignment rules</i>"; break;
+case "non potrà modifcare le <b>regole di assegnazione 1</b> nel":	$messaggio = "will not be able to modify the <b>assignment rules 1</b> in"; break;
+case "potrà modifcare le <b>regole di assegnazione 1</b> nel":	$messaggio = "will be able to modify the <b>assignment rules 1</b> in"; break;
+case "non potrà modifcare le <b>regole di assegnazione 2 e 3</b> nel":	$messaggio = "will not be able to modify the <b>assignment rules 2 and 3</b> in"; break;
+case "potrà modifcare le <b>regole di assegnazione 2 e 3</b> nel":	$messaggio = "will be able to modify the <b>assignment rules 2 and 3</b> in"; break;
+case "assegnazione persone":  			$messaggio = "people assignment"; break;
+case "Creazione e modifica delle pagine per il sito web":	$messaggio = "Create and modify website pages"; break;
+case "Solo con i costi aggiuntivi":  		$messaggio = "only with extra costs"; break;
+case "potrà creare e modificare le <b>pagine per il sito web</b>":	$messaggio = "will be able to create and modify <b>website pages</b>"; break;
+case "potrà modificare le <b>pagine per il sito web</b> solo quando crea e modifica i costi aggiuntivi":	$messaggio = "will be able to modify <b>website pages</b> only when creating and modifying extra costs"; break;
+case "non potrà più creare e modificare le <b>pagine per il sito web</b>":	$messaggio = "will not be able to create and modify <b>website pages</b>"; break;
+case "solo per tariffe":  			$messaggio = "only for rates"; break;
+case "per entrambi":  				$messaggio = "for both"; break;
+case "Modifica dei documenti in formato HTML":	$messaggio = "Modify documents in HTML format"; break;
+case "potrà modificare i <b>documenti con formato HTML</b>":	$messaggio = "will be able to modify <b>documents with HTML format</b>"; break;
+case "non potrà più modificare i <b>documenti con formato HTML</b>":	$messaggio = "will not be able to modify <b>documents with HTML format</b> anymore"; break;
+case "questo può consentire di portare attacchi di tipo \"Cross Site Scripting\" per rubare le credenziali di altri utenti":	$messaggio = "this could allow to carry out \"Cross Site Scripting\" attacks to steal other users' credentials"; break;
+case "Modifica delle password":  		$messaggio = "Modify passwords"; break;
+case "solo la propria":  			$messaggio = "only his own"; break;
+case "potrà modificare solo la sua <b>password</b>":	$messaggio = "will be able to modify only his own <b>password</b>"; break;
+case "non potrà più modificare le <b>password</b>":	$messaggio = "will not be able to modify <b>passwords</b>"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
 } # fine switch ($messaggio)
 
-?>
\ No newline at end of file
+?>
