@@ -100,8 +100,8 @@ case "Sei sicuro di voler <b>cancellare</b> la regola di assegnazione 2 per la":
 case "Sei sicuro di voler <b>cancellare</b> la regola di assegnazione 3 per la":	$messaggio = "Etes vous certain de vouloir <b>supprimer</b> la règle d'attribution 3 pour"; break;
 case "La regola di assegnazione è stata cancellata":	$messaggio = "La règle d'attribution a été supprimée"; break;
 case "La regola di assegnazione è già stata cancellata":	$messaggio = "La règle d'attribution a déjà été supprimée"; break;
-case "Tabella con le regole di assegnazione 1 del":	$messaggio = "Tableau avec les règles d'attribution 1 de"; break;
-case "Tabella con le regole di assegnazione 2 del":	$messaggio = "Tableau avec les règles d'attribution 2 de"; break;
+case "Tabella con le regole di assegnazione":	$messaggio = "Tableau avec les règles d'attribution"; break;
+case "del":					$messaggio = "de"; break;
 case "Tariffa":  				$messaggio = "Tarif"; break;
 case "Inserisci nuove regole":  		$messaggio = "Insérez une nouvelle règle"; break;
 case "Il numero inserito esiste già":  		$messaggio = "Le numéro inséré existe déjà"; break;
@@ -145,7 +145,6 @@ case "L'anno":  				$messaggio = "L'an"; break;
 case "è stato cancellato dal batabase":  	$messaggio = "a été supprimé de la base de données"; break;
 case "Non è stato possibile cancellare l'anno":	$messaggio = "Il n'a pas été possible de supprimer l'année"; break;
 case "dal database, controllare i permessi sulla cartella dati":	$messaggio = "de la base de données, vérifiez les permissions sur le fichier de dati"; break;
-case "Tabella con le regole di assegnazione 3 del":	$messaggio = "Tableau avec les règles d'attribution 3 de"; break;
 case "Utente":  				$messaggio = "Utilisateur"; break;
 case "Periodi_permessi":  			$messaggio = "Periodes_autorisees"; break;
 case "unico":  					$messaggio = "unique"; break;
@@ -194,6 +193,10 @@ case "in":  					$messaggio = "in"; break;
 case "giorno":  				$messaggio = "day"; break;
 case "p":  					$messaggio = "p"; break;
 case "Aggiungi":  				$messaggio = "Add"; break;
+case "e":  					$messaggio = "and"; break;
+case "Id":  					$messaggio = "Id"; break;
+case "chiedere":  				$messaggio = "ask"; break;
+case "Visualizza Tabelle":  			$messaggio = "View Tables"; break;
 case "Pers.":  					$messaggio = "Peop."; break;
 case "TOTALE":  				$messaggio = "TOTAL"; break;
 case "Tutte le spese del":  			$messaggio = "All expenses of"; break;
@@ -226,7 +229,6 @@ case "Modifica i campi della tabella":  	$messaggio = "Modify table fields"; bre
 case "documento di tipo":  			$messaggio = "document type"; break;
 case "visualizza":  				$messaggio = "view"; break;
 case "Vedi tutte le prenotazioni":  		$messaggio = "View all reservations"; break;
-case "Tabella con le regole di assegnazione 4 del":	$messaggio = "Table with the assignment rules 4 of"; break;
 case "Numero di persone":  			$messaggio = "Number of people"; break;
 case "assegna_se_":  				$messaggio = "assign_if_"; break;
 case "più_di_":  				$messaggio = "less_than_"; break;
@@ -360,9 +362,29 @@ case "escludere_da_totale_percentuale":  	$messaggio = "exclude_from_percentage_
 case "da varie tariffe":  			$messaggio = "from different<br>rates"; break;
 case "senza letti aggiuntivi":  		$messaggio = "without extra beds"; break;
 case "Premere per modificare":  		$messaggio = "Click to modify"; break;
+case "Converti definitivamente in":  		$messaggio = "Permanently convert into"; break;
+case "al cambio attuale":  			$messaggio = "at current exchange rate"; break;
+case "Le altre valute presenti nella cassa":  	$messaggio = "Other currencies in cashbox"; break;
+case "sono state convertite in":  		$messaggio = "have been converted into"; break;
+case "Tabella con le prenotazioni cancellate":	$messaggio = "Table with deleted reservations"; break;
+case "<b>non importare</b> i prezzi":  		$messaggio = "<b>do not import</b> prices"; break;
+case "Attenzione":  				$messaggio = "Notice"; break;
+case "i periodi aggiunti non potranno più essere eliminati":	$messaggio = "periods added now can't be deleted later"; break;
+case "come tipo di persona":  			$messaggio = "as person type"; break;
+case "e applica la % del tipo di persona":  	$messaggio = "and apply the % of person type"; break;
+case "escludendo":  				$messaggio = "excluding"; break;
+case "includendo solo":  			$messaggio = "including only"; break;
+case "Superato il massimo numero di anni comparabili":	$messaggio = "Exceeded the maximum number of comparable years"; break;
+case "Numero_predefinito di persone":  		$messaggio = "Default_number of people"; break;
+case "Numero_minimo di persone":  		$messaggio = "Minimum_number of people"; break;
+case "Cancellare anche":  			$messaggio = "Delete also"; break;
+case "clienti con solo prenotazioni cancellate negli anni passati, cancellando le loro prenotazioni in modo permanente":	$messaggio = "clients with only deleted reservations in past years, deleting their reservations permanently"; break;
+case "Prenotazioni cancellate":  		$messaggio = "Deleted reservations"; break;
+case "Anche cancellate":  			$messaggio = "Also deleted"; break;
+case "Solo cancellate":  			$messaggio = "Only deleted"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
 } # fine switch ($messaggio)
 
-?>
\ No newline at end of file
+?>
